@@ -3,7 +3,7 @@
 
 
 void sh_key::keyPressEvent ( QKeyEvent * event ){
-this->setText(QString("%1").arg(event->nativeVirtualKey()));
+this->setText(QString("%1").arg(event->nativeScanCode()));
 event->ignore();
 }
 
