@@ -18,11 +18,12 @@ MainWindow::MainWindow(QWidget *parent) :
     cycle=settings->value("cycle",1).toInt();
     frameskiping=settings->value("frame-skipping",0).toInt();
     save_slot=settings->value("saveslot",0).toInt();
+    selected_core=settings->value("selected_core","psx4m").toString();
 
     abbey=settings->value("abbey",false).toBool();
     logged=settings->value("logged",false).toBool();
     fscreen=settings->value("fullscreen",false).toBool();
-
+    accel=settings->value("accel",false).toBool();
 
     path = settings->value("rom-path","/home/user/MyDocs").toString();
 
@@ -40,6 +41,7 @@ dir.setNameFilters(QStringList()<<"*.bin"<<"*.iso"<<"*.img");
              roms.insert(o++,fileInfo.absoluteFilePath());
          }
          connect(ui->pushButton,SIGNAL(clicked()),this,SLOT(runGame()));
+connect(ui->listWidget,SIGNAL(currentTextChanged(QString)),this,SLOT(currentTextChanged(QString)));
 
 
          QMenu *fsk=new QMenu(tr("Frameskip"));
@@ -52,7 +54,7 @@ if (i==0)nam="Off";
              nm->setActionGroup(gr);
              nm->setCheckable(true);
              if (i==frameskiping)nm->setChecked(true);
-
+framem.append(nm);
          }
 
 
@@ -65,6 +67,7 @@ if (i==0)nam="Off";
              nm->setActionGroup(gr2);
              nm->setCheckable(true);
              if (i==cycle)nm->setChecked(true);
+             cyclem.append(nm);
          }
 
 
@@ -78,6 +81,18 @@ if (i==0)nam="Off";
              if (i==save_slot)nm->setChecked(true);
          }
 
+         QActionGroup *gr4=new QActionGroup(fsk);
+
+         QMenu *core=new QMenu(tr("Core"));
+         QStringList cores=QStringList()<<"psx4m"<<"gles"<<"pcsx";
+         for (int i=0;i<cores.count();i++){
+             QAction *nm=core->addAction(cores.at(i),this,SLOT(set_core()));
+             nm->setActionGroup(gr4);
+             nm->setCheckable(true);
+             if (cores.at(i)==selected_core)nm->setChecked(true);
+             corem.append(nm);
+         }
+
          QMenu *extra=new QMenu(tr("Extra"));
         /* ldbg=new QAction(tr("Create debug log"),&opt);
          ldbg->setCheckable(true);
@@ -99,6 +114,10 @@ if (i==0)nam="Off";
         fscr->setCheckable(true);
         fscr->setChecked(fscreen);
 
+        accelm=new QAction(tr("Accelometer"),&opt);
+        accelm->setCheckable(true);
+        accelm->setChecked(accel);
+
          abbm=new QAction(tr("Abe's Oddysee Fix"),&opt);
          abbm->setCheckable(true);
          abbm->setChecked(abbey);
@@ -112,6 +131,7 @@ if (i==0)nam="Off";
          opt.addMenu(fsk);
          opt.addMenu(cml);
          opt.addMenu(sav);
+         opt.addMenu(core);
          opt.addMenu(extra);
 
          extra->addAction(tr("Select directory"),this,SLOT(select_dir()));
@@ -154,6 +174,7 @@ if (i==0)nam="Off";
        //this->menuBar()->addAction(ldbg);
        this->menuBar()->addAction(fpsm);
        this->menuBar()->addAction(fscr);
+       this->menuBar()->addAction(accelm);
 }
 /*
 void MainWindow::show_log(){
@@ -230,6 +251,16 @@ void MainWindow::about(){
     dg.exec();
 }
 
+void MainWindow::currentTextChanged ( const QString & currentText ){
+    cycle=settings->value(QString("cycle[%1]").arg(currentText),0).toInt();
+    frameskiping=settings->value(QString("frame-skipping[%1]").arg(currentText),0).toInt();
+    selected_core=settings->value(QString("selected_core[%1]").arg(currentText),"psx4m").toString();
+cyclem.at(cycle)->setChecked(true);
+framem.at(frameskiping+1)->setChecked(true);
+ QStringList cores=QStringList()<<"psx4m"<<"gles"<<"pcsx";
+corem.at(cores.indexOf(selected_core))->setChecked(true);
+}
+
 void MainWindow::select_dir(){
     QString dir;
    QString directory=QFileDialog::getExistingDirectory(this,tr("Select directory"),dir,QFileDialog::ShowDirsOnly);
@@ -260,20 +291,37 @@ void MainWindow::save_ch(){
     settings->setValue("saveslot",save_slot);
 }
 
+void MainWindow::set_core(){
+    QAction *action = qobject_cast<QAction *>(sender());
+    selected_core=action->text();
+    if (ui->listWidget->currentRow()==-1)
+    settings->setValue("selected_core",selected_core);
+    else
+    settings->setValue(QString("selected_core[%1]").arg(ui->listWidget->currentItem()->text()) ,selected_core);
+}
+
 void MainWindow::fm_skip_ch(){
     QAction *action = qobject_cast<QAction *>(sender());
     frameskiping=action->text().toInt();
     if (action->text()=="Auto")frameskiping=-1;
     if (action->text()=="Off")frameskiping=0;
+    if (ui->listWidget->currentRow()==-1)
     settings->setValue("frame-skipping",frameskiping);
+    else
+    settings->setValue(QString("frame-skipping[%1]").arg(ui->listWidget->currentItem()->text()) ,frameskiping);
 }
 void MainWindow::cml_ch(){
     QAction *action = qobject_cast<QAction *>(sender());
     cycle=action->text().toInt();
+
+    if (ui->listWidget->currentRow()==-1)
     settings->setValue("cycle",cycle);
+    else
+    settings->setValue(QString("cycle[%1]").arg(ui->listWidget->currentItem()->text()) ,cycle);
 }
 
 void MainWindow::runGame(){
+    if (selected_core!="pcsx")
     if (!QFile("/home/user/MyDocs/scph1001.bin").exists()){
         QMessageBox msg;
         msg.setText(tr("Error! No bios found\nPut your bios at /home/user/MyDocs/scph1001.bin"));
@@ -288,25 +336,10 @@ void MainWindow::runGame(){
         return;}
 
     QString file=roms.value(ui->listWidget->currentRow());
-    /*
-./psx4m [options] [CD IMAGE FILE]
-        options:
-        -h -help --help This help
-        -runcd          Runs CdRom
-        -psxout         Enable stdout output
-        -load STATENUM  Loads savestate STATENUM (1-5)
-        -nosound        Disable sound
-        -showfps        Show FPS
-        -frameskip 0-8  Frame skipping ratio
-        -cyclemult 0-10 CPU cycle multiplier
-        -ilace 0,1,3,7  Interlace lines
-        FILE            CdRom file
-*/
 
 
 
-
-QString program = "/opt/maemo/usr/games/psx4m";
+QString program = "/opt/maemo/usr/games/"+selected_core;
 QStringList arguments;
 QProcess *myProcess = new QProcess();
 
@@ -323,6 +356,11 @@ if (ui->checkBox->isChecked())arguments<<"-nosound";
 if (fpsm->isChecked())arguments<<"-showfps";
 if (abbm->isChecked())arguments<<"-abbeyfix";
 if (fscr->isChecked())arguments<<"-fullscreen";
+if (accelm->isChecked())arguments<<"-accel";
+
+
+if (selected_core=="pcsx")
+    arguments<<"-cdfile";
 
 /*if (ldbg->isChecked()){
     arguments<<"-psxout";
@@ -332,7 +370,6 @@ if (fscr->isChecked())arguments<<"-fullscreen";
 
 
 arguments<<file;
-qDebug(QString("starting %1 %2").arg(program).arg(arguments.join(" ")).toAscii());
 
 
 myProcess->startDetached(program, arguments,"/home/user/");
@@ -347,6 +384,7 @@ MainWindow::~MainWindow()
    // settings->setValue("logged",ldbg->isChecked());
     settings->setValue("fullscreen",fscr->isChecked());
     settings->setValue("exit",eas->isChecked());
+    settings->setValue("accel",accelm->isChecked());
     settings->sync();
     delete ui;
 }
